@@ -116,7 +116,7 @@ def check_or_add_growth_rate(data: List[dict], value_key: str, growth_rate_key:
                 else:
                     if pre_value:
                         current = check_value(data[i].get(value_key, 0), 0) if data[i].get(value_key, 0) else 0
-                        value = float(current - pre_value) / pre_value if pre_value else 0
+                        value = float(current - pre_value) / abs(pre_value) if pre_value else 0
                     else:
                         value = 0
                     if flag:
@@ -127,7 +127,7 @@ def check_or_add_growth_rate(data: List[dict], value_key: str, growth_rate_key:
             else:
                 pre = check_value(data[i - 1].get(value_key, 0), 0) if data[i - 1].get(value_key, 0) else 0
                 current = check_value(data[i].get(value_key, 0), 0) if data[i].get(value_key, 0) else 0
-                value = float(current - pre) / pre if pre else 0
+                value = float(current - pre) / abs(pre) if pre else 0
                 if flag:
                     value = value * 100
                 if digits:
